@@ -2,6 +2,7 @@ package newapp
 
 import (
 	"bytes"
+	"context"
 	"fmt"
 	"io"
 	"io/ioutil"
@@ -270,10 +271,9 @@ func NewCmdNewApplication(name, baseName string, f kcmdutil.Factory, streams gen
 	o.PrintFlags.AddFlags(cmd)
 
 	cmd.Flags().BoolVar(&o.Config.AsTestDeployment, "as-test", o.Config.AsTestDeployment, "If true create this application as a test deployment, which validates that the deployment succeeds and then scales down.")
+	cmd.Flags().BoolVar(&o.Config.DeploymentConfig, "as-deployment-config", o.Config.DeploymentConfig, "If true create this application as a deployment config, which allows for hooks and custom strategies.")
 	cmd.Flags().StringSliceVar(&o.Config.SourceRepositories, "code", o.Config.SourceRepositories, "Source code to use to build this application.")
 	cmd.Flags().StringVar(&o.Config.ContextDir, "context-dir", o.Config.ContextDir, "Context directory to be used for the build.")
-	cmd.Flags().StringSliceVarP(&o.Config.ImageStreams, "image", "", o.Config.ImageStreams, "Name of an image stream to use in the app. (deprecated)")
-	cmd.Flags().MarkDeprecated("image", "use --image-stream instead")
 	cmd.Flags().StringSliceVarP(&o.Config.ImageStreams, "image-stream", "i", o.Config.ImageStreams, "Name of an image stream to use in the app.")
 	cmd.Flags().StringSliceVar(&o.Config.DockerImages, "docker-image", o.Config.DockerImages, "Name of a Docker image to include in the app.")
 	cmd.Flags().StringSliceVar(&o.Config.Templates, "template", o.Config.Templates, "Name of a stored template to use in the app.")
@@ -487,7 +487,7 @@ func (o *AppOptions) RunNewApp() error {
 				var route *routev1.Route
 				//check if route processing was completed and host field is prepopulated by router
 				err := wait.PollImmediate(500*time.Millisecond, RoutePollTimeout, func() (bool, error) {
-					route, err = config.RouteClient.Routes(t.Namespace).Get(t.Name, metav1.GetOptions{})
+					route, err = config.RouteClient.Routes(t.Namespace).Get(context.TODO(), t.Name, metav1.GetOptions{})
 					if err != nil {
 						return false, fmt.Errorf("Error while polling route %s", t.Name)
 					}
@@ -593,7 +593,7 @@ func followInstallation(config *newcmd.AppConfig, clientGetter genericclioptions
 
 func installationStarted(c corev1typedclient.PodInterface, name string, s corev1typedclient.SecretInterface) wait.ConditionFunc {
 	return func() (bool, error) {
-		pod, err := c.Get(name, metav1.GetOptions{})
+		pod, err := c.Get(context.TODO(), name, metav1.GetOptions{})
 		if err != nil {
 			return false, err
 		}
@@ -601,10 +601,10 @@ func installationStarted(c corev1typedclient.PodInterface, name string, s corev1
 			return false, nil
 		}
 		// delete a secret named the same as the pod if it exists
-		if secret, err := s.Get(name, metav1.GetOptions{}); err == nil {
+		if secret, err := s.Get(context.TODO(), name, metav1.GetOptions{}); err == nil {
 			if secret.Annotations[newcmd.GeneratedForJob] == "true" &&
 				secret.Annotations[newcmd.GeneratedForJobFor] == pod.Annotations[newcmd.GeneratedForJobFor] {
-				if err := s.Delete(name, nil); err != nil {
+				if err := s.Delete(context.TODO(), name, metav1.DeleteOptions{}); err != nil {
 					klog.V(4).Infof("Failed to delete install secret %s: %v", name, err)
 				}
 			}
@@ -615,7 +615,7 @@ func installationStarted(c corev1typedclient.PodInterface, name string, s corev1
 
 func installationComplete(c corev1typedclient.PodInterface, name string, out io.Writer) wait.ConditionFunc {
 	return func() (bool, error) {
-		pod, err := c.Get(name, metav1.GetOptions{})
+		pod, err := c.Get(context.TODO(), name, metav1.GetOptions{})
 		if err != nil {
 			if kapierrors.IsNotFound(err) {
 				return false, fmt.Errorf("installation pod was deleted; unable to determine whether it completed successfully")
@@ -625,7 +625,7 @@ func installationComplete(c corev1typedclient.PodInterface, name string, out io.
 		switch pod.Status.Phase {
 		case corev1.PodSucceeded:
 			fmt.Fprintf(out, "--> Success\n")
-			if err := c.Delete(name, nil); err != nil {
+			if err := c.Delete(context.TODO(), name, metav1.DeleteOptions{}); err != nil {
 				klog.V(4).Infof("Failed to delete install pod %s: %v", name, err)
 			}
 			return true, nil
@@ -774,20 +774,6 @@ func SetAnnotations(annotations map[string]string, result *newcmd.AppResult) err
 	return nil
 }
 
-// addDeploymentConfigNestedLabels adds new label(s) to a nested labels of a single DeploymentConfig object
-func addDeploymentConfigNestedLabels(obj *appsv1.DeploymentConfig, labels labels.Set) error {
-	if obj.Spec.Template == nil {
-		return nil
-	}
-	if obj.Spec.Template.Labels == nil {
-		obj.Spec.Template.Labels = make(map[string]string)
-	}
-	for k, v := range labels {
-		obj.Spec.Template.Labels[k] = v
-	}
-	return nil
-}
-
 func addObjectLabels(obj runtime.Object, labels labels.Set) error {
 	if labels == nil {
 		return nil
