@@ -1,6 +1,7 @@
 package project
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"net/url"
@@ -23,6 +24,7 @@ import (
 	projectv1client "github.com/openshift/client-go/project/clientset/versioned/typed/project/v1"
 	cliconfig "github.com/openshift/oc/pkg/helpers/kubeconfig"
 	clientcfg "github.com/openshift/oc/pkg/helpers/originkubeconfignames"
+	"github.com/openshift/oc/pkg/helpers/project"
 )
 
 type ProjectOptions struct {
@@ -156,14 +158,16 @@ func (o ProjectOptions) Run() error {
 		currentProject = currentContext.Namespace
 	}
 
+	client, kubeclient, err := o.ClientFn()
+	if err != nil {
+		return err
+	}
+	if err := client.RESTClient().Get().Resource("projectrequests").Do(context.TODO()).Into(&metav1.Status{}); err != nil {
+		return err
+	}
 	// No argument provided, we will just print info
 	if len(o.ProjectName) == 0 {
 		if len(currentProject) > 0 {
-			client, kubeclient, err := o.ClientFn()
-			if err != nil {
-				return err
-			}
-
 			switch err := ConfirmProjectAccess(currentProject, client, kubeclient); {
 			case kapierrors.IsForbidden(err), kapierrors.IsNotFound(err):
 				return fmt.Errorf("you do not have rights to view project %q specified in your config or the project doesn't exist", currentProject)
@@ -197,14 +201,14 @@ func (o ProjectOptions) Run() error {
 	// We have an argument that can be either a context or project
 	argument := o.ProjectName
 
-	contextInUse := ""
-	namespaceInUse := ""
+	var contextInUse, namespaceInUse, userNameInUse string
 
 	// Check if argument is an existing context, if so just set it as the context in use.
 	// If not a context then we will try to handle it as a project.
 	if context, contextExists := o.GetContextFromName(argument); contextExists {
 		contextInUse = argument
 		namespaceInUse = context.Namespace
+		userNameInUse = context.AuthInfo
 
 		config.CurrentContext = argument
 	} else {
@@ -247,8 +251,15 @@ func (o ProjectOptions) Run() error {
 			}
 		}
 		projectName := argument
+		if len(userNameInUse) == 0 {
+			user, err := project.WhoAmI(o.RESTConfig)
+			if err != nil {
+				return fmt.Errorf("unable to default to a user name: %v", err)
+			}
+			userNameInUse = user.Name
+		}
 
-		kubeconfig, err := cliconfig.CreateConfig(projectName, o.RESTConfig)
+		kubeconfig, err := cliconfig.CreateConfig(projectName, userNameInUse, o.RESTConfig)
 		if err != nil {
 			return err
 		}
@@ -309,13 +320,13 @@ func (o *ProjectOptions) GetContextFromName(contextName string) (*clientcmdapi.C
 }
 
 func ConfirmProjectAccess(currentProject string, projectClient projectv1client.ProjectV1Interface, kClient corev1client.CoreV1Interface) error {
-	_, projectErr := projectClient.Projects().Get(currentProject, metav1.GetOptions{})
+	_, projectErr := projectClient.Projects().Get(context.TODO(), currentProject, metav1.GetOptions{})
 	if !kapierrors.IsNotFound(projectErr) && !kapierrors.IsForbidden(projectErr) {
 		return projectErr
 	}
 
 	// at this point we know the error is a not found or forbidden, but we'll test namespaces just in case we're running on kube
-	if _, err := kClient.Namespaces().Get(currentProject, metav1.GetOptions{}); err == nil {
+	if _, err := kClient.Namespaces().Get(context.TODO(), currentProject, metav1.GetOptions{}); err == nil {
 		return nil
 	}
 
@@ -324,7 +335,7 @@ func ConfirmProjectAccess(currentProject string, projectClient projectv1client.P
 }
 
 func GetProjects(projectClient projectv1client.ProjectV1Interface, kClient corev1client.CoreV1Interface) ([]projectv1.Project, error) {
-	projects, err := projectClient.Projects().List(metav1.ListOptions{})
+	projects, err := projectClient.Projects().List(context.TODO(), metav1.ListOptions{})
 	if err == nil {
 		return projects.Items, nil
 	}
@@ -333,7 +344,7 @@ func GetProjects(projectClient projectv1client.ProjectV1Interface, kClient corev
 		return nil, err
 	}
 
-	namespaces, err := kClient.Namespaces().List(metav1.ListOptions{})
+	namespaces, err := kClient.Namespaces().List(context.TODO(), metav1.ListOptions{})
 	if err != nil {
 		return nil, err
 	}
